Settings
========

*  ``JOYOUS_HOLIDAYS``: Observed holidays - e.g. NZ[WGN]		
*  ``JOYOUS_GROUP_SELECTABLE``: Enable group selection? False or True		
*  ``JOYOUS_GROUP_MODEL``: To swap out the group model		
*  ``JOYOUS_TIME_INPUT``: Prompt for 12 or 24 hour times
*  ``JOYOUS_EVENTS_PER_PAGE``: Page limit for a list of events
*  ``JOYOUS_THEME_CSS``: Path of a theme CSS file to include.
*  ``JOYOUS_DATE_FORMAT``: Format of dates, if different from the Django standard.  Uses the same options as :ref:`django:date-and-time-formatting-specifiers`, plus 'X' which only gives the year if it is not the current year.
*  ``JOYOUS_DATE_SHORT_FORMAT``: Short format of dates, if different from the Django standard.  Uses the same options as ``JOYOUS_DATE_FORMAT``.
*  ``JOYOUS_TIME_FORMAT``: Format of times, if different from the Django standard.   Uses the same options as :ref:`django:date-and-time-formatting-specifiers`, plus 'q' which gives am or pm in lowercase.
